==> telegram-desktop_1.1.0.orig.tar.gz: tdesktop-1.1.0/Telegram/SourceFiles/mtproto/rsa_public_key.h <==
/*
This file is part of Telegram Desktop,
the official desktop version of Telegram messaging app, see https://telegram.org

Telegram Desktop is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

It is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

In addition, as a special exception, the copyright holders give permission
to link the code of portions of this program with the OpenSSL library.

Full license: https://github.com/telegramdesktop/tdesktop/blob/master/LICENSE
Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
*/
#pragma once

namespace MTP {
namespace internal {

// this class holds an RSA public key and can encrypt fixed-size messages with it
class RSAPublicKey final {
public:
	// key in RSAPublicKey "-----BEGIN RSA PUBLIC KEY----- ..." format
	RSAPublicKey() = default;
	explicit RSAPublicKey(base::const_byte_span key);
	RSAPublicKey(base::const_byte_span nBytes, base::const_byte_span eBytes);
	RSAPublicKey(RSAPublicKey &&other) = default;
	RSAPublicKey(const RSAPublicKey &other) = default;
	RSAPublicKey &operator=(RSAPublicKey &&other) = default;
	RSAPublicKey &operator=(const RSAPublicKey &other) = default;

	bool isValid() const;
	uint64 getFingerPrint() const;
	base::byte_vector getN() const;
	base::byte_vector getE() const;

	// data has exactly 256 chars to be encrypted
	base::byte_vector encrypt(base::const_byte_span data) const;

private:
	class Private;
	std::shared_ptr<Private> _private;

};

} // namespace internal
} // namespace MTP

==> telegram-desktop_1.1.23.orig.tar.gz: tdesktop-1.1.23/Telegram/SourceFiles/mtproto/rsa_public_key.h <==
/*
This file is part of Telegram Desktop,
the official desktop version of Telegram messaging app, see https://telegram.org

Telegram Desktop is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

It is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

In addition, as a special exception, the copyright holders give permission
to link the code of portions of this program with the OpenSSL library.

Full license: https://github.com/telegramdesktop/tdesktop/blob/master/LICENSE
Copyright (c) 2014-2017 John Preston, https://desktop.telegram.org
*/
#pragma once

namespace MTP {
namespace internal {

// this class holds an RSA public key and can encrypt fixed-size messages with it
class RSAPublicKey final {
public:
	// key in RSAPublicKey "-----BEGIN RSA PUBLIC KEY----- ..." format
	RSAPublicKey() = default;
	explicit RSAPublicKey(base::const_byte_span key);
	RSAPublicKey(base::const_byte_span nBytes, base::const_byte_span eBytes);
	RSAPublicKey(RSAPublicKey &&other) = default;
	RSAPublicKey(const RSAPublicKey &other) = default;
	RSAPublicKey &operator=(RSAPublicKey &&other) = default;
	RSAPublicKey &operator=(const RSAPublicKey &other) = default;

	bool isValid() const;
	uint64 getFingerPrint() const;
	base::byte_vector getN() const;
	base::byte_vector getE() const;

	// data has exactly 256 chars to be encrypted
	base::byte_vector encrypt(base::const_byte_span data) const;

	// data has exactly 256 chars to be decrypted
	base::byte_vector decrypt(base::const_byte_span data) const;

private:
	class Private;
	std::shared_ptr<Private> _private;

};

} // namespace internal
} // namespace MTP
